import asyncio
from autumn import Autumn


async def main():
    client = Autumn(
        token="am_sk_test_zzKIp2wyp6QkCsUekw7OOGC4tqQg1AdfLAFFiXpDtG")

    res = await client.checkout(customer_id="123", product_id="pro")
    print(res)

    await client.close()


if __name__ == "__main__":
    asyncio.run(main())



from .client import *
from .error import *
from .models.meta import *
from .models.balance import *
from .models.customers import *
from .models.features import *
from .models.products import *
from .aio.client import AsyncClient as Autumn

__title__ = "autumn"
__version__ = "1.5.2"
__license__ = "MIT"
__author__ = "justanotherbyte"
__copyright__ = "Copyright 2025 justanotherbyte"


BASE_URL = "https://api.useautumn.com"
VERSION = "v1"
